@@ -28,7 +28,6 @@ from gopup.index.index_weibo import weibo_index
 from gopup.index.index_toutiao import (
     toutiao_index,
     toutiao_relation,
-    toutiao_sentiment,
     toutiao_province,
     toutiao_city,
     toutiao_age,
@@ -49,7 +48,10 @@ from gopup.index.index_google import (
 """
 百度迁徙地图接口
 """
-from gopup.event.area_baidu import migration_area_baidu
+from gopup.event.area_baidu import (
+    migration_area_baidu,
+    migration_scale_baidu
+)
 
 
 """
